@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # coding=utf-8
 import pyinotify
-import os
+import os, glob
 import re
 import logging
 from string import Template
@@ -39,16 +39,20 @@ class Rules(dict):
     '''rules parsed from Inactionfile'''
     def __init__(self, acfile='Inactionfile'):
         def parse_line(l):
-            pathname,events,command = [ s.strip() for s in re.split('\s+', l, 2) ]
+            pathnames,events,command = [ s.strip() for s in re.split('\s+', l, 2) ]
 
-            pathname = os.path.realpath(pathname)
             events = [ pyinotify.EventsCodes.ALL_FLAGS.get(flag.strip())
                      for flag in events.split(',') ]
 
             if None in events:
                 raise InactionfileError('Not recognized event type')
 
-            self[pathname] = Rule(pathname, events, command)
+            # support multiple files in one rule
+            for pathname in pathnames.split(','):
+                for pathname in glob.glob(pathname):
+                    # support Unix style pathname pattern expansion in pathname
+                    pathname = os.path.realpath(pathname)
+                    self[pathname] = Rule(pathname, events, command)
 
         with open(acfile) as f:
             for l in f:
